@@ -2,18 +2,18 @@
 #     Copyright (C) 2005 Stewart Adam
 #    This file is part of NewInstall.
 
-#    FWBackups is free software; you can redistribute it and/or modify
+#    NewInstall is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
 #    (at your option) any later version.
 
-#    FWBackups is distributed in the hope that it will be useful,
+#    NewInstall is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 
 #    You should have received a copy of the GNU General Public License
-#    along with FWBackups; if not, write to the Free Software
+#    along with NewInstall; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 echo 'Fedora Core 4 initial setup script by [S|G], Firewing1 & contributors (see CHANGELOG)'
@@ -21,7 +21,7 @@ echo 'Fedora Core 4 initial setup script by [S|G], Firewing1 & contributors (see
 gethelp()
 {
 echo -e '\nNEW! Please check out our handy how-to'\''s and tips! \nThey include how to manually do everything that is done, here, in this script, and more such as CD ripping, microphones, and video codecs! \nWould you like to view them now? (y for yes, n for no, c to cancel/exit)'
-read -n 1 tmp
+tmp=n
 if [ "$tmp" = "y" ]; then
  if [ "$(which firefox &> /dev/null; echo $?)" = "0" ]; then
   firefox files/web/index.html
@@ -47,6 +47,9 @@ clear
 }
 #gethelp       NOT COMPLETE *YET*
 
+
+
+
 ######## GUI #########
 askquit()
 {
@@ -55,6 +58,8 @@ then
 kill 0
 fi
 }
+
+
 gui()
 {
 ROOT_UID=0   # Root has $UID 0.
@@ -63,22 +68,44 @@ toinstall=""
 if [ "$UID" -eq "$ROOT_UID" ]
 then
 echo '..........................................................'
-echo 'Configuring YUM - Livna'
-rm -f /etc/yum.conf
-wget --directory-prefix=/etc/ http://www.fedorafaq.org/samples/yum.conf
-rpm -Uvh http://www.fedorafaq.org/yum --replacefiles
-if [ "echo $?" == "0" ]
-then
- echo 'Success. Starting GUI.'
+echo 'Configuring YUM - Livna & RPMForge'
+## CHECK LIVNA ##
+if [ -e "/etc/yum.repos.d/livna.repo" ];then
+echo "livna.repo exists. Skipping."
 else
- echo 'Failed. Starting GUI Anyways.'
+echo "livna.repo non-existant. Adding in disabled state."
+echo '
+[livna]
+name=Livna for Fedora Core $releasever - $basearch - Base
+baseurl=
+        http://rpm.livna.org/fedora/$releasever/$basearch/RPMS.lvn
+        http://livna.cat.pdx.edu/fedora/$releasever/$basearch/RPMS.lvn
+        http://wftp.tu-chemnitz.de/pub/linux/livna/fedora/$releasever/$basearch/RPMS.lvn
+        http://ftp-stud.fht-esslingen.de/pub/Mirrors/rpm.livna.org/fedora/$releasever/$basearch/RPMS.lvn
+failovermethod=priority
+enabled=0' > /etc/yum.repos.d/livna.repo
+echo 'Done.'
 fi
+## CHECK RPMFORGE ##
+if [ -e "/etc/yum.repos.d/livna.repo" ];then
+echo "rpmforge.repo exists. Skipping."
+else
+echo "rpmforge.repo non-existant. Adding in disabled state."
+echo '
+[rpmforge]
+name=Fedora Core 4 - i386 - RPMforge.net - dries
+mirrorlist=http://apt.sw.be/dries/fedora/fc4/mirrors-rpmforge
+enabled=0' > /etc/yum.repos.d/rpmforge.repo
+echo 'Done.'
+fi
+
 other()
 {
 toinstall="$toinstall $(zenity --list --title "Other Tools" --checklist --column "" --column "Keyword" --column "Description"  --separator " " \
 "" "java" "Install Sun Java JRE" \
 "" "mstt" "Install MS TrueType fonts" \
 "" "FWSuite" "Install FWBackups (An automated backup solution)" \
+"" "Wine" "Wine Windows Emulator -- Run Windows apps in Linux!" \
 --height=400 --width=500)"
 if [ "$(echo $?)" != "0" ]
 then
@@ -290,7 +317,7 @@ yum="1"
 
 FWSuite()
 {
-rpm -Uhv files/FWBackups-1.3-5.noarch.rpm
+rpm -Uhv files/FWBackups-1.4-0.noarch.rpm
 }
 
 serverconf()
@@ -320,6 +347,19 @@ serverconf()
  fi
 }
 
+Wine()
+{
+wine="wine wine-tools"
+yum="1"
+if [ "$(rpm -q arts --qf '%{NAME}')" == "arts" ];then
+wine="$wine wine-arts"
+fi
+wget http://ds80-237-203-29.dedicated.hosteurope.de/wt/winetools-0.9-3jo.i386.rpm -O ./files/winetools-0.9-3jo.i386.rpm
+wget http://ftp.belnet.be/packages/dries.ulyssis.org/fedora/fc4/i386/RPMS.dries/xdialog-2.1.2-1.2.fc4.rf.i386.rpm -o ./files/xdialog-2.1.2-1.2.fc4.rf.i386.rpm
+rpm -Uhv ./files/xdialog-2.1.2-1.2.fc4.rf.i386.rpm
+rpm -Uhv ./files/winetools-0.9-3jo.i386.rpm
+}
+
 #yum will only run at this point if anything was set for installing
 parse_all()
 {
@@ -333,12 +373,12 @@ install_all()
 {
 if [ "$yum" = "1" ]
 then
- yum -y install $amams $ntfs $kde $ati $nvidia $rbox $lamp $devel $amule $bittorrent
+ yum -y install --enablerepo=livna --enablerepo=rpmforge $amams $ntfs $kde $ati $nvidia $rbox $lamp $devel $amule $bittorrent $wine
 fi
 #installs stuff that need atrpms if any was chosen
 if [ "$yum2" = "1" ]
 then
- yum -y --enablerepo=atrpms install $codec $mplayer
+ yum -y --enablerepo=atrpms --enablerepo=livna --enablerepo=rpmforge install $codec $mplayer
 fi
 clear
 }
@@ -387,7 +427,7 @@ update
 #At this point we will install kernel module updates
 if [ "$pi" = "1" ]
 then
- yum -y install $nvd2 $ntfs2 $ati2
+ yum -y --enablerepo=livna --enablerepo=rpmforge install $nvd2 $ntfs2 $ati2
 fi
 echo "You may need to reboot to complete setup."
 else
@@ -417,11 +457,36 @@ if [ "$UID" -eq "$ROOT_UID" ]
 then
 
 echo '..........................................................'
-echo 'Configuring YUM - Livna'
-rm -f /etc/yum.conf
-wget --directory-prefix=/etc/ http://www.fedorafaq.org/samples/yum.conf
-rpm -Uvh http://www.fedorafaq.org/yum
-clear
+echo 'Configuring YUM - Livna & RPMForge'
+## CHECK LIVNA ##
+if [ -e "/etc/yum.repos.d/livna.repo" ];then
+echo "livna.repo exists. Skipping."
+else
+echo "livna.repo non-existant. Adding in disabled state."
+echo '
+[livna]
+name=Livna for Fedora Core $releasever - $basearch - Base
+baseurl=
+        http://rpm.livna.org/fedora/$releasever/$basearch/RPMS.lvn
+        http://livna.cat.pdx.edu/fedora/$releasever/$basearch/RPMS.lvn
+        http://wftp.tu-chemnitz.de/pub/linux/livna/fedora/$releasever/$basearch/RPMS.lvn
+        http://ftp-stud.fht-esslingen.de/pub/Mirrors/rpm.livna.org/fedora/$releasever/$basearch/RPMS.lvn
+failovermethod=priority
+enabled=0' > /etc/yum.repos.d/livna.repo
+echo 'Done.'
+fi
+## CHECK RPMFORGE ##
+if [ -e "/etc/yum.repos.d/livna.repo" ];then
+echo "rpmforge.repo exists. Skipping."
+else
+echo "rpmforge.repo non-existant. Adding in disabled state."
+echo '
+[rpmforge]
+name=Fedora Core 4 - i386 - RPMforge.net - dries
+mirrorlist=http://apt.sw.be/dries/fedora/fc4/mirrors-rpmforge
+enabled=0' > /etc/yum.repos.d/rpmforge.repo
+echo 'Done.'
+fi
 
 #This will install MS truetype fonts from corefonts rpm packages
 fonts_install()
@@ -496,7 +561,7 @@ install_flash()
 echo 'Install flash? (y for yes, n for no, c to cancel/exit)'
 read -n 1 tmp
 if [ "$tmp" = "y" ]; then
- yum -y --enablerepo=flash install flash-plugin
+ yum -y --enablerepo=livna --enablerepo=rpmforge --enablerepo=flash install flash-plugin
 elif [ "$tmp" = "n" ]; then
  clear
 elif [ "$tmp" = "c" ]; then
@@ -767,11 +832,11 @@ LAMP
 
 FWSuite()
 {
- echo 'Install FWBackups v1.3-4, an automated backup solution?'
+ echo 'Install FWBackups v1.4-0, an automated backup solution?'
 echo '(y for yes, n for no, c to cancel/exit)'
  read -n 1 tmp
  if [ "$tmp" = "y" ]; then
-   rpm -Uhv files/FWBackups-1.3-4.noarch.rpm
+   rpm -Uhv files/FWBackups-1.4-0.noarch.rpm
  elif [ "$tmp" = "n" ]; then
   clear
  elif [ "$tmp" = "c" ]; then
@@ -809,15 +874,32 @@ serverconf()
 }
 serverconf
 
+wine()
+{
+Wine()
+{
+echo "Install Wine Windows Emulator, allowing you to run Windows applications on Linux?"
+wine="wine wine-tools"
+yum="1"
+if [ "$(rpm -q arts --qf '%{NAME}')" == "arts" ];then
+wine="$wine wine-arts"
+fi
+wget http://ds80-237-203-29.dedicated.hosteurope.de/wt/winetools-0.9-3jo.i386.rpm -O ./files/winetools-0.9-3jo.i386.rpm
+wget http://ftp.belnet.be/packages/dries.ulyssis.org/fedora/fc4/i386/RPMS.dries/xdialog-2.1.2-1.2.fc4.rf.i386.rpm -o ./files/xdialog-2.1.2-1.2.fc4.rf.i386.rpm
+rpm -Uhv ./files/xdialog-2.1.2-1.2.fc4.rf.i386.rpm
+rpm -Uhv ./files/winetools-0.9-3jo.i386.rpm
+}
+}
+wine
 #yum will only run at this point if anything was set for installing
 if [ $yum = "1" ]
 then
- yum -y install $xmms $ntfs $kde $ati $nvidia $rbox $amarok $lamp $devel $amule $bittorrent
+ yum -y install --enablerepo=livna --enablerepo=rpmforge $xmms $ntfs $kde $ati $nvidia $rbox $amarok $lamp $devel $amule $bittorrent $wine
 fi
 #installs stuff that need atrpms if any was chosen
 if [ $yum2 = "1" ]
 then
- yum -y --enablerepo=atrpms install $codec $mplayer $codec2
+ yum -y --enablerepo=atrpms --enablerepo=livna --enablerepo=rpmforge install $codec $mplayer $codec2
 fi
 clear
 
@@ -829,15 +911,11 @@ echo 'ATTENTION! At this point we will update your entire system. This may take
 echo 'Press Y to continue with the update (recommended) or any other key to skip this step.'
 read -n 1 tmp
 if [ "$tmp" = "y" ]; then
-	echo 'Updating your system... This may take a LOT of time, depending on how many packages must be installed. Grab some cofee and watch some TV.'
+	echo -e 'Updating your system... \nThis may take a lot of time, depending on how many packages must be installed.\n Grab some cofee and watch some TV.\n\n(If your system is up-to-date, this should only take a few seconds. If your system is out of date, it can take easily take a half an hour.)'
 	yum -y update
 	clear
-	#echo 'Please note that you may have to reinstall your Graphics driver and the NTFS driver if your kernel was updated.'
-	#echo 'You can easily do that by running this script again after rebooting and choosing to install the modules again.'
-	#echo 'If you just installed those modules, you dont have to worry as they will be automatically updated as well.'
-	#echo 'Press enter to continue.'
 	read -n 1 tmp
-#If we chose to install nvidia drivers, we'll also install them for any newer kernell installed with the update at this point
+#If we chose to install nvidia drivers, we'll also install them for any newer kernel installed with the update at this point
         if [ $nvd = "y" ]
 	then
 	 nvd2="kernel-module-nvidia-$(rpm -q --queryformat="%{version}-%{release}\n" kernel | tail -n 1)"
@@ -849,7 +927,7 @@ if [ "$tmp" = "y" ]; then
 	 ntfs2="kernel-module-ntfs-$(rpm -q --queryformat="%{version}-%{release}\n" kernel | tail -n 1)"
 	 pi="1" 
 	fi
-#If we chose to install ATI drivers, we'll also install them for any newer kernell installed with the update at this point
+#If we chose to install ATI drivers, we'll also install them for any newer kernel installed with the update at this point
 	if [ $ati = "y" ] 
 	then
 	 ati2="ati-fglrx kernel-module-fglrx-$(rpm -q --queryformat="%{version}-%{release}\n" kernel | tail -n 1)"
@@ -866,7 +944,7 @@ update
 #At this point we will install kernel module updates
 if [ "$pi" = "1" ]
 then
- yum -y install $nvd2 $ntfs2 $ati2
+ yum -y install --enablerepo=livna --enablerepo=rpmforge $nvd2 $ntfs2 $ati2
 fi
 echo "You may need to reboot to complete setup."
 else
@@ -884,7 +962,7 @@ if [ "$tmp" = "y" ]; then
   echo -e '\n'
   gui
   else
-  echo -e "Please install Zenity. You can do to with:\n user@host:#$ su -c 'rpm -e zenity;yum install gnome-utils'"
+  echo -e "Please install Zenity. You can do to with:\n\t$ su -c 'rpm -e zenity;yum install gnome-utils'"
  fi
 elif [ "$tmp" = "n" ]; then
   echo -e '\n'
